encode_avro

Function encode_avro 

pub fn encode_avro<T: Serialize>(schema: &Schema, value: &T) -> Result<Vec<u8>>
Encode a serializable value to Avro binary using the given schema.

Used when publishing events to the Salesforce Pub/Sub API.

Errors

Returns PubSubError::Avro if the value cannot be serialized or resolved against the provided schema.