Avro codec utilities for encoding and decoding Salesforce Pub/Sub events.
Salesforce Pub/Sub events are encoded as Avro binary (not JSON).
Each event carries a schema_id in its header that identifies the Avro
schema required for decoding.
Functions
- decode_
avro - Decode Avro-binary bytes into a
serde_json::Valueusing the given schema. - decode_
avro_ typed - Decode Avro-binary bytes directly into a typed struct
Tusing the given schema. - encode_
avro - Encode a serializable value to Avro binary using the given schema.